"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const tslib_1 = require("tslib");
const react_1 = tslib_1.__importStar(require("react"));
const CheckMarkCircleSVG_1 = tslib_1.__importDefault(require("./CheckMarkCircleSVG"));
const AlertCircleSVG_1 = tslib_1.__importDefault(require("./AlertCircleSVG"));
const Toaster_1 = tslib_1.__importDefault(require("./Toaster"));
function EmailField({ onSubmit }) {
    const [formError, setFormError] = (0, react_1.useState)(null);
    const [isSubmitted, setIsSubmitted] = (0, react_1.useState)(false);
    const [email, setEmail] = (0, react_1.useState)('');
    const [showNotification, setShowNotification] = react_1.default.useState(false);
    const validate = () => {
        if (email.length > 0 && /^[^\s@]+@[^\s@]+\.[^\s@]+$/.test(email)) {
            setFormError(null);
            return true;
        }
        setFormError({ type: 'validate', message: 'Please enter a valid email address' });
        return false;
    };
    const handleSubmit = (e) => tslib_1.__awaiter(this, void 0, void 0, function* () {
        e.preventDefault();
        const isValid = validate();
        if (!isValid)
            return;
        try {
            yield onSubmit(email);
            setIsSubmitted(true);
        }
        catch (_e) {
            setFormError({
                type: 'callback',
                message: 'Sorry, there was an error sending. Please try again.',
            });
        }
    });
    const onCloseToaster = () => {
        setShowNotification(false);
        setIsSubmitted(false);
        setFormError(null);
    };
    (0, react_1.useEffect)(() => {
        if (isSubmitted || (formError === null || formError === void 0 ? void 0 : formError.type) === 'callback') {
            setShowNotification(true);
        }
    }, [isSubmitted, formError === null || formError === void 0 ? void 0 : formError.type]);
    return (react_1.default.createElement("div", { className: 'cio-share-results-feature-group' },
        react_1.default.createElement("form", { onSubmit: handleSubmit },
            react_1.default.createElement("div", { className: 'cio-share-results-description' }, "Share by email"),
            react_1.default.createElement("div", { className: 'cio-share-results-button-group' },
                react_1.default.createElement("div", { className: 'cio-share-results-email-input-group' },
                    react_1.default.createElement("input", { className: `cio-share-results-email-input ${formError ? 'cio-share-results-email-input--error' : ''}`, onChange: (e) => setEmail(e.target.value), placeholder: 'Enter an email address to receive and share the results' }),
                    (formError === null || formError === void 0 ? void 0 : formError.type) === 'validate' && (react_1.default.createElement("div", { className: 'cio-share-results-email-input-error-message' }, formError.message))),
                react_1.default.createElement("button", { className: 'cio-share-results-share-button', type: 'submit' }, "Send"))),
        showNotification && (react_1.default.createElement(Toaster_1.default, { icon: isSubmitted ? CheckMarkCircleSVG_1.default : AlertCircleSVG_1.default, message: isSubmitted ? 'Email sent' : formError === null || formError === void 0 ? void 0 : formError.message, onCloseToaster: onCloseToaster }))));
}
exports.default = EmailField;
