"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const react_1 = require("react");
const useQueryParams = () => {
    const getParsedQueryParam = (queryName) => {
        if (typeof window === 'undefined')
            return [];
        const queryParams = new URLSearchParams(window.location.search);
        const queryParam = queryParams.get(queryName);
        if (!queryParam)
            return [];
        return queryParam === null || queryParam === void 0 ? void 0 : queryParam.split(',');
    };
    const queryItems = getParsedQueryParam('items');
    const queryAttributes = getParsedQueryParam('attributes');
    const isSharedResultsQuery = !!queryItems.length && !!queryAttributes.length;
    const removeSharedResultsQueryParams = (0, react_1.useCallback)(() => {
        if (typeof window === 'undefined')
            return;
        const updatedUrl = new URL(window.location.href);
        updatedUrl.searchParams.delete('items');
        updatedUrl.searchParams.delete('attributes');
        if (!updatedUrl.searchParams.toString().length) {
            updatedUrl.search = '';
        }
        window.history.replaceState({}, '', updatedUrl.toString());
    }, []);
    return {
        queryItems,
        queryAttributes,
        isSharedResultsQuery,
        removeSharedResultsQueryParams,
    };
};
exports.default = useQueryParams;
